package jrummikub.model;

import java.util.ArrayList;
import java.util.Collection;
import java.util.EnumSet;
import java.util.List;
import java.util.Random;

/**
 * StoneHeap creates all {@link Stone}s for a game, manages them and allows
 * players to draw one or more random Stones.
 */

public class StoneHeap {
	List<Stone> heap;
	Random generator = new Random();

	/** Creates 106 Stones according to standard rules */
	public StoneHeap() {
		heap = new ArrayList<Stone>();
		for (int i = 1; i <= 13; i++) {
			for (int j = 0; j < 2; j++) {
				for (StoneColor c : EnumSet.allOf(StoneColor.class)) {
					heap.add(new Stone(i, c));
				}
			}
		}
		// Joker
		heap.add(new Stone(StoneColor.BLACK));
		heap.add(new Stone(StoneColor.RED));
	}

	/**
	 * Removes random {@link Stone} from the heap and returns it
	 * 
	 * @return the drawn stone
	 */
	public Stone drawStone() {
		return heap.remove(generator.nextInt(heap.size()));
	}

	/**
	 * Removes several {@link Stone}s from the heap and returns them
	 * 
	 * @param number
	 *          number of requested Stones
	 * @return list of drawn stones
	 */
	public List<Stone> drawStones(int number) {
		List<Stone> drawnStones = new ArrayList<Stone>();
		for (int i = 0; i < number; i++) {
			drawnStones.add(drawStone());
		}
		return drawnStones;
	}

	public int getSize() {
		return heap.size();
	}

	public void putBack(Collection<Stone> stones) {
		heap.addAll(stones);
	}
}
